package com.xkrs.controller;

import com.xkrs.common.encapsulation.PromptMessageEnum;
import com.xkrs.common.tool.TokenUtil;
import com.xkrs.model.entity.SysUserEntity;
import com.xkrs.model.vo.MemberApplicationVo;
import com.xkrs.model.vo.MemberJoinVo;
import com.xkrs.service.MemberProjectService;
import com.xkrs.service.SysUserService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import static com.xkrs.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @author XinYi Song
 */
@RestController
public class MemberProjectController {

    @Resource
    private MemberProjectService memberProjectService;

    @Resource
    private SysUserService sysUserService;


    /**
     * 成员进行加入和退出的操作
     * @param map
     * @param token
     * @return
     */
    @PostMapping("/memberOperate")
    @PreAuthorize("hasAnyAuthority('auth_administor','auth_general_user')")
    public String memberOperate(@RequestBody Map map,@RequestHeader(value="Authorization") String token){
        String projectNumber = (String) map.get("projectNumber");
        String keepType = (String) map.get("keepType");
        if("1".equals(keepType)){
            String s = memberProjectService.memberJoin(projectNumber, token);
            return s;
        }else {
            return memberProjectService.memberDropOut(projectNumber,token);
        }
    }

    /**
     * 查询该项目加入的成员的信息
     * @param projectNumber
     * @param token
     * @return
     */
    @GetMapping("/selectMemberJoin")
    @PreAuthorize("hasAnyAuthority('auth_administor','auth_general_user')")
    public String selectMemberJoin(@RequestParam("projectNumber") String projectNumber,@RequestHeader(value="Authorization") String token){
        // 获取区域信息
        Locale locale = LocaleContextHolder.getLocale();
        // 验证token
        String tokenUserName = TokenUtil.getTokenUserName(token);
        SysUserEntity sysUserByUserName = sysUserService.getSysUserByUserName(tokenUserName);
        if(sysUserByUserName == null){
            return outputEncapsulationObject(PromptMessageEnum.USER_LOGIN_ERROR,"您还没有注册登录，请先注册登录",locale);
        }
        List<MemberJoinVo> memberJoinVos = memberProjectService.selectMemberJoin(projectNumber);
        if(memberJoinVos == null || memberJoinVos.size() == 0){
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE,"暂时还没有任何成员的信息",locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,memberJoinVos,locale);
    }


}
