package com.xkrs.controller;

import com.xkrs.common.encapsulation.PromptMessageEnum;
import com.xkrs.common.tool.TokenUtil;
import com.xkrs.dao.ResponsibleProjectDao;
import com.xkrs.model.entity.ResponsibleProject;
import com.xkrs.model.entity.SysUserEntity;
import com.xkrs.model.vo.ApplicationProjectVo;
import com.xkrs.service.MemberProjectService;
import com.xkrs.service.ResponsibleProjectService;
import com.xkrs.service.SysUserService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import static com.xkrs.common.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @author XinYi Song
 */
@RestController
public class ResponsibleProjectController {

    @Resource
    private ResponsibleProjectService responsibleProjectService;

    @Resource
    private SysUserService sysUserService;

    @Resource
    private ResponsibleProjectDao responsibleProjectDao;

    @Resource
    private MemberProjectService memberProjectService;

    /**
     * 管理员对项目进行开始，结束的操作
     * @param map
     * @param token
     * @return
     */
    @PostMapping("/operateResponsible")
    @PreAuthorize("hasAnyAuthority('auth_administor')")
    public String operateResponsible(@RequestBody Map map,@RequestHeader(value="Authorization") String token){
        String projectNumber = (String) map.get("projectNumber");
        String keepType = (String) map.get("keepType");
        if("1".equals(keepType)){
            return responsibleProjectService.operateResponsible(projectNumber,token);
        }else {
            return responsibleProjectService.operateOver(projectNumber,token);
        }
    }

    /**
     * 管理员对负责人的进行授权和撤销授权的操作
     * @param map
     * @param token
     * @return
     */
    @PreAuthorize("hasAnyAuthority('auth_administor')")
    @PostMapping("/operateResponsibleApplication")
    public String operateResponsibleApplication(@RequestBody Map map,@RequestHeader(value="Authorization") String token){
        String projectNumber = (String) map.get("projectNumber");
        String keepType = (String) map.get("keepType");
        Integer userId = (Integer) map.get("userId");
        // 获取区域信息
        Locale locale = LocaleContextHolder.getLocale();
        // 验证token
        String tokenUserName = TokenUtil.getTokenUserName(token);
        SysUserEntity sysUserByUserName = sysUserService.getSysUserByUserName(tokenUserName);
        if(sysUserByUserName == null){
            return outputEncapsulationObject(PromptMessageEnum.USER_LOGIN_ERROR,"您还没有注册登录，请先注册登录",locale);
        }
        if("1".equals(keepType)){
            return responsibleProjectService.adminAllow(projectNumber,userId);
        }else {
            return responsibleProjectService.adminRefuse(projectNumber,userId);
        }
    }

    /**
     * 查询当前用户管理，提交审核，参与的项目的编号
     * @param token
     * @return
     */
    @GetMapping("/selectManaAndParNumber")
    @PreAuthorize("hasAnyAuthority('auth_administor','auth_general_user')")
    public String selectManaAndParNumber(@RequestHeader(value="Authorization") String token){
        Map map = new HashMap(3);
        // 获取区域信息
        Locale locale = LocaleContextHolder.getLocale();
        // 验证token
        String tokenUserName = TokenUtil.getTokenUserName(token);
        SysUserEntity sysUserByUserName = sysUserService.getSysUserByUserName(tokenUserName);
        if(sysUserByUserName == null){
            return outputEncapsulationObject(PromptMessageEnum.USER_LOGIN_ERROR,"您还没有注册登录，请先注册登录",locale);
        }
        // 查询管理的项目的编号
        List<String> strings = responsibleProjectService.selectProjectNumberByPrincipalId(sysUserByUserName.getId());
        map.put("manage",strings);
        // 查询参与的项目的编号
        List<String> strings2 = memberProjectService.selectProjectNumberByMemberId(sysUserByUserName.getId());
        map.put("participate",strings2);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS,map,locale);
    }
}
