package com.xkrs.dao;

import com.xkrs.model.entity.ResponsibleProject;
import com.xkrs.model.vo.ApplicationProjectVo;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @author XinYi Song
 */
@Component
public interface ResponsibleProjectDao extends JpaRepository<ResponsibleProject,Long>, JpaSpecificationExecutor<ResponsibleProject> {

    /**
     * 修改审核状态
     * @param auditType
     * @param projectNumber
     */
    @Query(value = "update responsible_project set audit_type = ?1 where responsible_project_number = ?2",nativeQuery = true)
    @Modifying(clearAutomatically=true)
    void updateAuditType(String auditType,String projectNumber);

    /**
     * 修改项目的开始时间
     * @param startTime
     * @param projectNumber
     */
    @Query(value = "update responsible_project set start_time = ?1 where responsible_project_number = ?2",nativeQuery = true)
    @Modifying(clearAutomatically=true)
    void updateStartTime(String startTime,String projectNumber);

    /**
     * 修改项目负责人的id
     * @param userId
     * @param projectNumber
     */
    @Query(value = "update responsible_project set principal_id = ?1 where responsible_project_number = ?2",nativeQuery = true)
    @Modifying(clearAutomatically=true)
    void updatePrincipalIdByProjectNumber(Integer userId,String projectNumber);

    /**
     * 根据用户id和项目编号查询改天信息
     * @param userId
     * @param projectNumber
     * @return
     */
    ResponsibleProject findByPrincipalIdAndResponsibleProjectNumber(Integer userId,String projectNumber);

    /**
     * 根据项目编号查询项目
     * @param responsibleProjectNumber
     * @return
     */
    ResponsibleProject findByResponsibleProjectNumber(String responsibleProjectNumber);

    /**
     * 查询负责人申请时的相关信息
     * @param projectNumber
     * @return
     */
    @Query(value = "select new com.xkrs.model.vo.ApplicationProjectVo (po.projectNumber,po.projectName,su.reallyName,rp.applicationTime,rp.principalId) " +
            "from SysUserEntity su,ResponsibleProject rp,ProjectOverview po where rp.responsibleProjectNumber = po.projectNumber " +
            "and rp.principalId = su.id and rp.responsibleProjectNumber = :projectNumber")
    ApplicationProjectVo selectApplicationInformation(@Param("projectNumber") String projectNumber);

    /**
     * 查询管理的项目的编号
     * @param userId
     * @param auditType
     * @return
     */
    @Query(value = "select responsible_project_number from responsible_project where principal_id = ?1 and audit_type = ?2",nativeQuery = true)
    List<String> selectProjectNumberByPrincipalId(Integer userId,String auditType);

    /**
     * 根据项目编号删除信息
     * @param projectNumber
     */
    @Modifying(clearAutomatically=true)
    void deleteByResponsibleProjectNumber(String projectNumber);
}
